@@ -446,11 +446,11 @@ def write_employees_worksheet(workbook, employee_groups):
 
 
 
-def get_employee_groups():
+def get_employee_groups(project_id):
     db = get_db()
     employees = db.execute(
-        'SELECT id, name, description'
-        ' FROM employee_group'
+        'SELECT id, name, description, project_id'
+        ' FROM employee_group WHERE project_id = ?', (project_id,)
     ).fetchall()
 
     return employees
@@ -542,7 +542,7 @@ def export_as_excel(project_id):
 
     countermeasures_of_project = get_countermeasures_of_project(project_id)
 
-    emp_groups = get_employee_groups()
+    emp_groups = get_employee_groups(project_id)
 
     chart_data = []
     colors = ['#011f4b', '#03396c', '#005b96', '#6497b1', '#b3cde0',
@@ -653,7 +653,7 @@ def awareness_dashboard(project_id):
     awarenessmeasures_this_month = [x for x in awarenessmeasures if x['due_date'] is not None and x['due_date'] > this_month_start and x['due_date'] < next_month_start]
     awarenessmeasures_next_month = [x for x in awarenessmeasures if x['due_date'] is not None and x['due_date'] > next_month_start and x['due_date'] < two_months_ahead_start]
     awarenessmeasures_without_date = [x for x in awarenessmeasures if x['due_date'] is None]
-    awarenessmeasures_with_legal_attention = [x for x in awarenessmeasures if x['needs_legal_attention'] is not None and x['needs_legal_attention'] == 1]
+    awarenessmeasures_with_legal_attention = [x for x in awarenessmeasures if x['needs_legal_attention'] is not None and (x['needs_legal_attention'] == 1 or x['needs_legal_attention'] is True)]
 
     session['selected_project'] = project_id
 
